import stan                       #   pystan --> stan
import matplotlib.pyplot as plt
import numpy as np
import arviz as az


RawData = [[1,  1, 0, 0, 1, 0, 0],
           [1,  1, 0, 0, 0, 1, 0],
           [10, 1, 0, 0, 0, 0, 1],
           [3,  0, 1, 0, 1, 0, 0],
           [2,  0, 1, 0, 0, 1, 0],
           [10, 0, 1, 0, 0, 0, 1],
           [6,  0, 0, 1, 1, 0, 0],
           [2,  0, 0, 1, 0, 1, 0],
           [4,  0, 0, 1, 0, 0, 1]]

F = []
Xr1 = []
Xr2 = []
Xr3 = []
Xc1 = []
Xc2 = []
Xc3 = []
for v in RawData:
    F.append(v[0])
    Xr1.append(v[1])
    Xr2.append(v[2])
    Xr3.append(v[3])
    Xc1.append(v[4])
    Xc2.append(v[5])
    Xc3.append(v[6])

for i in range(9):
    print(' ', F[i], '  ', Xr1[i], '  ', Xr2[i], '  ', Xr3[i],
          '  ', Xc1[i], '  ', Xc2[i], '  ', Xc3[i])

N = 9
Data = {'N': N, 'F': F, 'Xr1': Xr1, 'Xr2': Xr2, 'Xr3': Xr3,
        'Xc1': Xc1, 'Xc2': Xc2, 'Xc3': Xc3}

#sm = pystan.StanModel(file = 'Poisson.stan')
#fit = sm.sampling(data = Data,
#                  pars = ['mu', 'a2', 'a3', 'b2', 'b3',
#                          'g22', 'g23', 'g32', 'g33'], n_jobs = 1)
with open('Poisson.stan', 'r') as f_stan:
    sm = stan.build(f_stan.read(), data = Data)
    fit = sm.sample()
#print(fit)
i_data = az.from_pystan(posterior = fit, posterior_model = sm)
summary = az.summary(i_data, var_names = ['mu', 'a2', 'a3', 'b2', 'b3',
                                         'g22', 'g23', 'g32', 'g33'])
print(summary)

d_frame = fit.to_frame()
a3 = d_frame['a3']
ck_a3 = a3 > 0  
print('P(a3 > 0.0) =', np.sum(ck_a3)/len(ck_a3))
b3 = d_frame['b3']
ck_b3 = b3 > 0  
print('P(b3 > 0.0) =', np.sum(ck_b3)/len(ck_b3))
g33 = d_frame['g33']
ck_g33 = g33 < 0 
print('P(g33 < 0.0) =',np.sum(ck_g33)/len(ck_g33))
